@@ -1,13 +1,15 @@
+from __future__ import absolute_import
 
-
-__version__ = '4.5.0'
-
+from traits._version import full_version as __version__
 
 # Add a NullHandler so 'traits' loggers don't complain when they get used.
 import logging
 
-class NullHandler(logging.Handler):
 
+__requires__ = ["six"]
+
+
+class NullHandler(logging.Handler):
     def handle(self, record):
         pass
 
@@ -17,6 +19,7 @@ class NullHandler(logging.Handler):
     def createLock(self):
         self.lock = None
 
+
 logger = logging.getLogger(__name__)
 logger.addHandler(NullHandler())
 
