@@ -11,7 +11,7 @@
 
 from __future__ import absolute_import
 
-from traits.testing.unittest_tools import unittest
+import unittest
 
 try:
     import numpy
@@ -54,6 +54,3 @@ class ArrayTestCase(unittest.TestCase):
         self.assertEqual(f.event_fired, True)
 
         return
-
-
-#### EOF ######################################################################
